@@ -1521,7 +1521,8 @@ totem_pl_parser_parse_internal (TotemPlParser *parser,
 				DEBUG (file, g_print ("Using %s function for '%s'\n", special_types[i].mimetype, uri));
 				ret = (* special_types[i].func) (parser, file, base_file, data);
 
-				g_object_unref (base_file);
+				if (base_file != NULL)
+					g_object_unref (base_file);
 
 				found = TRUE;
 				break;
@@ -1548,7 +1549,8 @@ totem_pl_parser_parse_internal (TotemPlParser *parser,
 
 				ret = (* dual_types[i].func) (parser, file, base_file ? base_file : file, data);
 
-				g_object_unref (base_file);
+				if (base_file != NULL)
+					g_object_unref (base_file);
 
 				found = TRUE;
 				break;
@@ -1565,7 +1567,7 @@ totem_pl_parser_parse_internal (TotemPlParser *parser,
 		return ret;
 	}
 
-	if (totem_pl_parser_ignore_from_mimetype (parser, mimetype)) {
+	if (totem_pl_parser_ignore_from_mimetype (parser, mimetype) != FALSE) {
 		g_free (mimetype);
 		return TOTEM_PL_PARSER_RESULT_IGNORED;
 	}
@@ -1655,10 +1657,15 @@ void
 totem_pl_parser_add_ignored_scheme (TotemPlParser *parser,
 		const char *scheme)
 {
+	char *s;
+
 	g_return_if_fail (TOTEM_IS_PL_PARSER (parser));
 
+	s = g_strdup (scheme);
+	if (s[strlen (s) - 1] == ':')
+		s[strlen (s) - 1] = '\0';
 	parser->priv->ignore_schemes = g_list_prepend
-		(parser->priv->ignore_schemes, g_strdup (scheme));
+		(parser->priv->ignore_schemes, s);
 }
 
 /**
